pub struct ClipBoxFormat2<'a> {
data: FontData<'a>,
}Expand description
ClipBoxFormat2 record
Fields
data: FontData<'a>Implementations
Sourceimpl ClipBoxFormat2<'_>
impl ClipBoxFormat2<'_>
fn v1_closure(&self, c: &mut Colrv1ClosureContext<'_>)
Sourceimpl<'a> ClipBoxFormat2<'a>
impl<'a> ClipBoxFormat2<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn var_index_base(&self) -> u32
pub fn var_index_base(&self) -> u32
Base index into DeltaSetIndexMap.
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn x_min_byte_range(&self) -> Range<usize> ⓘ
pub fn y_min_byte_range(&self) -> Range<usize> ⓘ
pub fn x_max_byte_range(&self) -> Range<usize> ⓘ
pub fn y_max_byte_range(&self) -> Range<usize> ⓘ
pub fn var_index_base_byte_range(&self) -> Range<usize> ⓘ