pub struct PaintColrGlyph<'a> {
data: FontData<'a>,
}Expand description
PaintColrGlyph table
Fields
data: FontData<'a>Implementations
Sourceimpl PaintColrGlyph<'_>
impl PaintColrGlyph<'_>
fn v1_closure(&self, c: &mut Colrv1ClosureContext<'_>)
Sourceimpl<'a> PaintColrGlyph<'a>
impl<'a> PaintColrGlyph<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn glyph_id_byte_range(&self) -> Range<usize> ⓘ