pub struct PaintColrLayers<'a> {
data: FontData<'a>,
}Expand description
PaintColrLayers table
Fields
data: FontData<'a>Implementations
Sourceimpl PaintColrLayers<'_>
impl PaintColrLayers<'_>
fn v1_closure(&self, c: &mut Colrv1ClosureContext<'_>)
Sourceimpl<'a> PaintColrLayers<'a>
impl<'a> PaintColrLayers<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn num_layers(&self) -> u8
pub fn num_layers(&self) -> u8
Number of offsets to paint tables to read from LayerList.
Sourcepub fn first_layer_index(&self) -> u32
pub fn first_layer_index(&self) -> u32
Index (base 0) into the LayerList.
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn num_layers_byte_range(&self) -> Range<usize> ⓘ
pub fn first_layer_index_byte_range(&self) -> Range<usize> ⓘ