PaintSkewAroundCenter

Struct PaintSkewAroundCenter 

pub struct PaintSkewAroundCenter<'a> {
    data: FontData<'a>,
}
Fields

data: FontData<'a>

Implementations

Source

impl PaintSkewAroundCenter<'_>

fn v1_closure(&self, c: &mut Colrv1ClosureContext<'_>)

Source

impl<'a> PaintSkewAroundCenter<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn format(&self) -> u8

Set to 30.

pub fn paint_offset(&self) -> Offset24

Offset to a Paint subtable.

pub fn paint(&self) -> Result<Paint<'a>, ReadError>

Attempt to resolve paint_offset.

pub fn x_skew_angle(&self) -> F2Dot14

Angle of skew in the direction of the x-axis, 180° in counter-clockwise degrees per 1.0 of value.

pub fn y_skew_angle(&self) -> F2Dot14

Angle of skew in the direction of the y-axis, 180° in counter-clockwise degrees per 1.0 of value.

pub fn center_x(&self) -> FWord

x coordinate for the center of rotation.

pub fn center_y(&self) -> FWord

y coordinate for the center of rotation.

pub fn format_byte_range(&self) -> Range<usize>

pub fn paint_offset_byte_range(&self) -> Range<usize>

pub fn x_skew_angle_byte_range(&self) -> Range<usize>

pub fn y_skew_angle_byte_range(&self) -> Range<usize>

pub fn center_x_byte_range(&self) -> Range<usize>

pub fn center_y_byte_range(&self) -> Range<usize>