pub struct PaintVarSweepGradient<'a> {
data: FontData<'a>,
}Expand description
PaintVarSweepGradient table
Fields
data: FontData<'a>Implementations
Sourceimpl PaintVarSweepGradient<'_>
impl PaintVarSweepGradient<'_>
fn v1_closure(&self, c: &mut Colrv1ClosureContext<'_>)
Sourceimpl<'a> PaintVarSweepGradient<'a>
impl<'a> PaintVarSweepGradient<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn color_line_offset(&self) -> Offset24
pub fn color_line_offset(&self) -> Offset24
Offset to VarColorLine table.
Sourcepub fn color_line(&self) -> Result<VarColorLine<'a>, ReadError>
pub fn color_line(&self) -> Result<VarColorLine<'a>, ReadError>
Attempt to resolve color_line_offset.
Sourcepub fn start_angle(&self) -> F2Dot14
pub fn start_angle(&self) -> F2Dot14
Start of the angular range of the gradient, 180° in counter-clockwise degrees per 1.0 of value. For variation, use varIndexBase + 2.
Sourcepub fn end_angle(&self) -> F2Dot14
pub fn end_angle(&self) -> F2Dot14
End of the angular range of the gradient, 180° in counter-clockwise degrees per 1.0 of value. For variation, use varIndexBase + 3.
Sourcepub fn var_index_base(&self) -> u32
pub fn var_index_base(&self) -> u32
Base index into DeltaSetIndexMap.
pub fn format_byte_range(&self) -> Range<usize> ⓘ
pub fn color_line_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn center_x_byte_range(&self) -> Range<usize> ⓘ
pub fn center_y_byte_range(&self) -> Range<usize> ⓘ
pub fn start_angle_byte_range(&self) -> Range<usize> ⓘ
pub fn end_angle_byte_range(&self) -> Range<usize> ⓘ
pub fn var_index_base_byte_range(&self) -> Range<usize> ⓘ