pub struct VarAffine2x3<'a> {
data: FontData<'a>,
}Expand description
VarAffine2x3 record
Fields
data: FontData<'a>Implementations
Sourceimpl VarAffine2x3<'_>
impl VarAffine2x3<'_>
fn v1_closure(&self, c: &mut Colrv1ClosureContext<'_>)
Sourceimpl<'a> VarAffine2x3<'a>
impl<'a> VarAffine2x3<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn xx(&self) -> Fixed
pub fn xx(&self) -> Fixed
x-component of transformed x-basis vector. For variation, use varIndexBase + 0.
Sourcepub fn yx(&self) -> Fixed
pub fn yx(&self) -> Fixed
y-component of transformed x-basis vector. For variation, use varIndexBase + 1.
Sourcepub fn xy(&self) -> Fixed
pub fn xy(&self) -> Fixed
x-component of transformed y-basis vector. For variation, use varIndexBase + 2.
Sourcepub fn yy(&self) -> Fixed
pub fn yy(&self) -> Fixed
y-component of transformed y-basis vector. For variation, use varIndexBase + 3.
Sourcepub fn var_index_base(&self) -> u32
pub fn var_index_base(&self) -> u32
Base index into DeltaSetIndexMap.
pub fn xx_byte_range(&self) -> Range<usize> ⓘ
pub fn yx_byte_range(&self) -> Range<usize> ⓘ
pub fn xy_byte_range(&self) -> Range<usize> ⓘ
pub fn yy_byte_range(&self) -> Range<usize> ⓘ
pub fn dx_byte_range(&self) -> Range<usize> ⓘ
pub fn dy_byte_range(&self) -> Range<usize> ⓘ
pub fn var_index_base_byte_range(&self) -> Range<usize> ⓘ